==> sal-wechat-2.21.1-20170313.084940-5-sources.jar: com/baijia/tianxiao/sal/wechat/helper/qrcode/WechatQRCodeLinkHelper.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2015-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.wechat.helper.qrcode;

import java.io.File;

import com.baijia.tianxiao.constant.Flag;
import com.baijia.tianxiao.constants.MIMEType;
import com.baijia.tianxiao.dto.upload.UploadResult;
import com.baijia.tianxiao.exception.WebServiceException;
import com.baijia.tianxiao.exception.WechatException;
import com.baijia.tianxiao.sal.wechat.dto.qrcode.QRCodeDto;
import com.baijia.tianxiao.sal.wechat.dto.qrcode.QRCodeSceneStrActivity;
import com.baijia.tianxiao.sal.wechat.dto.qrcode.QRCodeSceneStrSubscribeOrg;
import com.baijia.tianxiao.sal.wechat.dto.wechatapi.WechatApiResponse;
import com.baijia.tianxiao.sal.wechat.util.FileUploadUtils;
import com.baijia.tianxiao.sal.wechat.util.LocalFileHelper;

import net.sf.json.JSONObject;

/**
 * @title : WechatQRCodeLinkHelper
 * @description :
 * @author : zhenyujian
 * @date : 2016年1月28日 上午11:36:59
 */
public class WechatQRCodeLinkHelper {

	
	
    public static QRCodeDto getQRCodeDto(String accessToken) {
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, "");
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));
        return dto;
    }

    
    
    public static QRCodeDto getQRCodeDtoForCustomActivity(String accessToken, int activityId, int activityType) {
        QRCodeSceneStrActivity activity = new QRCodeSceneStrActivity(activityId, activityType);
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, activity.getSceneStr().toString());
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));

        return dto;
    }

    
    
    public static QRCodeDto getQRCodeDtoForCustomActivity(String accessToken, int originOrgId, int activityId, int activityType) {
        QRCodeSceneStrActivity activity = new QRCodeSceneStrActivity(activityId, activityType, originOrgId);
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, activity.getSceneStr().toString());
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));

        return dto;
    }
    
    
    
    public static QRCodeDto getQRCodeDtoForSubscribeWithOrgId(String accessToken, Integer orgId){
    	QRCodeSceneStrSubscribeOrg qrCode = new QRCodeSceneStrSubscribeOrg(orgId);
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, qrCode.getSceneStr().toString());
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));

        return dto;
    }

    
    
    public static byte[] downloadQRCodeImage(String ticket) throws WechatException, WebServiceException, Exception {
        return WechatQRCodeCaller.downloadQRCodeImage(ticket);
    }

    
    
    public static String getGsxImgUrl(QRCodeDto qrCodeDto) throws Exception{
    	File localFile = null;
        String qrCodeImgUrl;
        try {
            byte[] data = WechatQRCodeLinkHelper.downloadQRCodeImage(qrCodeDto.getTicket());
            localFile = LocalFileHelper.saveToLocal(data, MIMEType.JPG);
            UploadResult result = FileUploadUtils.uploadToRemote(Flag.NULL.getLong(), localFile, false);
            qrCodeImgUrl = result.getFiles().get(0).getUrl();
        } catch (Exception e) {
            throw e;
        } finally {
            if (localFile != null) {
                LocalFileHelper.deleteFile(localFile);
            }
        }
        return qrCodeImgUrl;
    }
}

==> sal-wechat-2.31.0-20170731.032814-25-sources.jar: com/baijia/tianxiao/sal/wechat/helper/qrcode/WechatQRCodeLinkHelper.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2015-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.wechat.helper.qrcode;

import java.io.File;

import com.baijia.tianxiao.constant.Flag;
import com.baijia.tianxiao.constants.MIMEType;
import com.baijia.tianxiao.dto.upload.UploadResult;
import com.baijia.tianxiao.exception.WebServiceException;
import com.baijia.tianxiao.exception.WechatException;
import com.baijia.tianxiao.sal.wechat.dto.qrcode.QRCodeDto;
import com.baijia.tianxiao.sal.wechat.dto.qrcode.QRCodeSceneStrActivity;
import com.baijia.tianxiao.sal.wechat.dto.qrcode.QRCodeSceneStrSubscribeOrg;
import com.baijia.tianxiao.sal.wechat.dto.wechatapi.WechatApiResponse;
import com.baijia.tianxiao.sal.wechat.util.FileUploadUtils;
import com.baijia.tianxiao.sal.wechat.util.LocalFileHelper;

import lombok.NonNull;
import net.sf.json.JSONObject;

/**
 * @title : WechatQRCodeLinkHelper
 * @description :
 * @author : zhenyujian
 * @date : 2016年1月28日 上午11:36:59
 */
public class WechatQRCodeLinkHelper {

	
	
    public static QRCodeDto getQRCodeDto(String accessToken) {
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, "");
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));
        return dto;
    }

    
    
    public static QRCodeDto getQRCodeDtoForCustomActivity(String accessToken, int activityId, int activityType) {
        QRCodeSceneStrActivity activity = new QRCodeSceneStrActivity(activityId, activityType);
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, activity.getSceneStr().toString());
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));

        return dto;
    }
    
    public static QRCodeDto getQRCodeDtoForOneMonth(@NonNull String accessToken, int sceneId) {
        WechatApiResponse response = WechatQRCodeCaller.createTemporaryQRCode(accessToken, sceneId);
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));
        dto.setExpireSeconds(rootNode.getLong("expire_seconds"));
        
        return dto;
    }
    
    public static QRCodeDto getQRCodeDtoForCustomActivity(String accessToken, int originOrgId, int activityId, int activityType) {
        QRCodeSceneStrActivity activity = new QRCodeSceneStrActivity(activityId, activityType, originOrgId);
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, activity.getSceneStr().toString());
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));

        return dto;
    }
    
    
    
    public static QRCodeDto getQRCodeDtoForSubscribeWithOrgId(String accessToken, Integer orgId){
    	QRCodeSceneStrSubscribeOrg qrCode = new QRCodeSceneStrSubscribeOrg(orgId);
        WechatApiResponse response = WechatQRCodeCaller.createPermanentQRCode(accessToken, qrCode.getSceneStr().toString());
        JSONObject rootNode = response.getRootJSONObj();

        QRCodeDto dto = new QRCodeDto();
        dto.setTicket(rootNode.getString("ticket"));
        dto.setUrl(rootNode.getString("url"));

        return dto;
    }

    
    
    public static byte[] downloadQRCodeImage(String ticket) throws WechatException, WebServiceException, Exception {
        return WechatQRCodeCaller.downloadQRCodeImage(ticket);
    }

    
    
    public static String getGsxImgUrl(QRCodeDto qrCodeDto) throws Exception{
    	File localFile = null;
        String qrCodeImgUrl;
        try {
            byte[] data = WechatQRCodeLinkHelper.downloadQRCodeImage(qrCodeDto.getTicket());
            localFile = LocalFileHelper.saveToLocal(data, MIMEType.JPG);
            UploadResult result = FileUploadUtils.uploadToRemote(Flag.NULL.getLong(), localFile, false);
            qrCodeImgUrl = result.getFiles().get(0).getUrl();
        } catch (Exception e) {
            throw e;
        } finally {
            if (localFile != null) {
                LocalFileHelper.deleteFile(localFile);
            }
        }
        return qrCodeImgUrl;
    }
}
